@@ -39,17 +39,17 @@ def getSinRegression(X,Y1):
     y1=np.array(Y1)
     x=x.astype(float)
     y1=y1.astype(float)
-    print(x)
+    #print(x)
     global popt
     popt, pcov=curve_fit(func1,x, y1, p0=[1]*len(x))
-    y=func1(X, *popt)
-    return x,y
+
+    return x,func1(x, *popt)
     #popt, pcov=curve_fit(func2,x, y1, p0=[0]*len(x))
 
 def plotRegression():
     plt.figure("picture function")
     plt.plot(x,func1(x,*popt),label="RegressionFunction")
-    print(x)
+    #print(x)
     plt.xlabel("num")
     plt.ylabel("f")
     plt.legend()
